@@ -89,7 +89,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_0 = {
   "KTBM learned exchange - 0",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm0, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -105,7 +105,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_1 = {
   "KTBM learned exchange - 1",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm1, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -121,7 +121,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_2 = {
   "KTBM learned exchange - 2",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm2, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -137,7 +137,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_3 = {
   "KTBM learned exchange - 3",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm3, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -153,7 +153,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_4 = {
   "KTBM learned exchange - 4",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm4, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -169,7 +169,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_5 = {
   "KTBM learned exchange - 5",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm5, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -185,7 +185,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_6 = {
   "KTBM learned exchange - 6",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm6, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -201,7 +201,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_7 = {
   "KTBM learned exchange - 7",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm7, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -217,7 +217,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_8 = {
   "KTBM learned exchange - 8",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm8, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -233,7 +233,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_9 = {
   "KTBM learned exchange - 9",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm9, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -249,7 +249,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_10 = {
   "KTBM learned exchange - 10",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm10, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -265,7 +265,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_11 = {
   "KTBM learned exchange - 11",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm11, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -281,7 +281,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_12 = {
   "KTBM learned exchange - 12",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm12, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -297,7 +297,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_13 = {
   "KTBM learned exchange - 13",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm13, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -313,7 +313,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_14 = {
   "KTBM learned exchange - 14",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm14, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -329,7 +329,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_15 = {
   "KTBM learned exchange - 15",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm15, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -345,7 +345,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_16 = {
   "KTBM learned exchange - 16",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm16, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -361,7 +361,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_17 = {
   "KTBM learned exchange - 17",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm17, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -377,7 +377,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_18 = {
   "KTBM learned exchange - 18",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm18, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -393,7 +393,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_19 = {
   "KTBM learned exchange - 19",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm19, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -409,7 +409,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_20 = {
   "KTBM learned exchange - 20",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm20, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -425,7 +425,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_21 = {
   "KTBM learned exchange - 21",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm21, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -441,7 +441,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_22 = {
   "KTBM learned exchange - 22",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm22, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -457,7 +457,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_23 = {
   "KTBM learned exchange - 23",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm23, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -473,7 +473,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_24 = {
   "KTBM learned exchange - 24",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbm24, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
@@ -489,7 +489,7 @@ const xc_func_info_type xc_func_info_mgga_x_ktbm_gap = {
   "KTBM learned exchange - GAP",
   XC_FAMILY_MGGA,
   {&xc_ref_Kovacs2022_094110, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR_KTBM, ktbm_names, ktbm_desc, par_ktbmgap, set_ext_params_cpy},
   mgga_x_ktbm_init, NULL,
