@@ -23,7 +23,7 @@ const xc_func_info_type xc_func_info_mgga_x_mcml = {
   "MCML exchange",
   XC_FAMILY_MGGA,
   {&xc_ref_Brown2021_2004, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-14,
   {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
